@@ -1,7 +1,7 @@
 package App::riap;
 
-our $DATE = '2016-03-10'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $DATE = '2016-08-18'; # DATE
+our $VERSION = '0.36'; # VERSION
 
 use 5.010001;
 use strict;
@@ -548,7 +548,7 @@ sub comp_ {
             array=>\@res, word=>$word0),
     });
     if ($self->setting("debug_completion")) {
-        say "DEBUG: Completion: ".join(", ", @$comp);
+        say "DEBUG: Completion (1): ".join(", ", @$comp);
     }
     @$comp;
 }
@@ -701,6 +701,14 @@ sub _install_cmds {
                 extras => {-shell => $self},
             );
             $res = _hashify_compres($res);
+
+            # [ux] for cd, we want the convenience of directly completing single
+            # directory name without offering the choice of '--help', '-h',
+            # '../' etc unless the word contains that word
+            if ($cmd eq 'cd' && $words->[$cword] !~ /^[.-]/) {
+                $res->{words} = [ grep { !/^[.-]/ } @{ $res->{words} } ];
+            }
+
             my $comp = Complete::Bash::format_completion({
                 path_sep => '/',
                 as       => 'array',
@@ -709,7 +717,7 @@ sub _install_cmds {
                     array=>$res->{words}, word=>$word),
             });
             if ($self->setting('debug_completion')) {
-                say "DEBUG: Completion: ".join(", ", @$comp);
+                say "DEBUG: Completion (2): ".join(", ", @$comp);
             }
             @$comp;
         };
@@ -737,7 +745,7 @@ App::riap - Riap command-line client shell
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -753,6 +761,8 @@ This is the backend/implementation of the C<riap> script.
 
 L<Perinci::Access>
 
+L<peri-access>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
